# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Document(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Document - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'change_number': 'int',
            'date_created': 'datetime',
            'date_modified': 'datetime',
            'date_uploaded': 'datetime',
            'content_uri': 'str',
            'workspace': 'UriReference',
            'created_by': 'UriReference',
            'uploaded_by': 'UriReference',
            'content_type': 'str',
            'content_length': 'int',
            'system_type': 'str',
            'filename': 'str',
            'page_count': 'int',
            'read': 'bool',
            'caller_address': 'str',
            'receiver_address': 'str',
            'tags': 'list[str]',
            'tag_values': 'list[TagValue]',
            'attributes': 'list[DocumentAttribute]',
            'thumbnails': 'list[DocumentThumbnail]',
            'upload_status': 'UriReference',
            'upload_destination_uri': 'str',
            'upload_method': 'str',
            'lock_info': 'LockInfo',
            'acl': 'list[str]',
            'sharing_status': 'str',
            'sharing_uri': 'str',
            'download_sharing_uri': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'change_number': 'changeNumber',
            'date_created': 'dateCreated',
            'date_modified': 'dateModified',
            'date_uploaded': 'dateUploaded',
            'content_uri': 'contentUri',
            'workspace': 'workspace',
            'created_by': 'createdBy',
            'uploaded_by': 'uploadedBy',
            'content_type': 'contentType',
            'content_length': 'contentLength',
            'system_type': 'systemType',
            'filename': 'filename',
            'page_count': 'pageCount',
            'read': 'read',
            'caller_address': 'callerAddress',
            'receiver_address': 'receiverAddress',
            'tags': 'tags',
            'tag_values': 'tagValues',
            'attributes': 'attributes',
            'thumbnails': 'thumbnails',
            'upload_status': 'uploadStatus',
            'upload_destination_uri': 'uploadDestinationUri',
            'upload_method': 'uploadMethod',
            'lock_info': 'lockInfo',
            'acl': 'acl',
            'sharing_status': 'sharingStatus',
            'sharing_uri': 'sharingUri',
            'download_sharing_uri': 'downloadSharingUri',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._change_number = None
        self._date_created = None
        self._date_modified = None
        self._date_uploaded = None
        self._content_uri = None
        self._workspace = None
        self._created_by = None
        self._uploaded_by = None
        self._content_type = None
        self._content_length = None
        self._system_type = None
        self._filename = None
        self._page_count = None
        self._read = False
        self._caller_address = None
        self._receiver_address = None
        self._tags = None
        self._tag_values = None
        self._attributes = None
        self._thumbnails = None
        self._upload_status = None
        self._upload_destination_uri = None
        self._upload_method = None
        self._lock_info = None
        self._acl = None
        self._sharing_status = None
        self._sharing_uri = None
        self._download_sharing_uri = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Document.
        The globally unique identifier for the object.

        :return: The id of this Document.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Document.
        The globally unique identifier for the object.

        :param id: The id of this Document.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Document.


        :return: The name of this Document.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Document.


        :param name: The name of this Document.
        :type: str
        """
        self._name = name

    @property
    def change_number(self):
        """
        Gets the change_number of this Document.


        :return: The change_number of this Document.
        :rtype: int
        """
        return self._change_number

    @change_number.setter
    def change_number(self, change_number):
        """
        Sets the change_number of this Document.


        :param change_number: The change_number of this Document.
        :type: int
        """
        self._change_number = change_number

    @property
    def date_created(self):
        """
        Gets the date_created of this Document.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_created of this Document.
        :rtype: datetime
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this Document.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_created: The date_created of this Document.
        :type: datetime
        """
        self._date_created = date_created

    @property
    def date_modified(self):
        """
        Gets the date_modified of this Document.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this Document.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this Document.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this Document.
        :type: datetime
        """
        self._date_modified = date_modified

    @property
    def date_uploaded(self):
        """
        Gets the date_uploaded of this Document.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_uploaded of this Document.
        :rtype: datetime
        """
        return self._date_uploaded

    @date_uploaded.setter
    def date_uploaded(self, date_uploaded):
        """
        Sets the date_uploaded of this Document.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_uploaded: The date_uploaded of this Document.
        :type: datetime
        """
        self._date_uploaded = date_uploaded

    @property
    def content_uri(self):
        """
        Gets the content_uri of this Document.


        :return: The content_uri of this Document.
        :rtype: str
        """
        return self._content_uri

    @content_uri.setter
    def content_uri(self, content_uri):
        """
        Sets the content_uri of this Document.


        :param content_uri: The content_uri of this Document.
        :type: str
        """
        self._content_uri = content_uri

    @property
    def workspace(self):
        """
        Gets the workspace of this Document.


        :return: The workspace of this Document.
        :rtype: UriReference
        """
        return self._workspace

    @workspace.setter
    def workspace(self, workspace):
        """
        Sets the workspace of this Document.


        :param workspace: The workspace of this Document.
        :type: UriReference
        """
        self._workspace = workspace

    @property
    def created_by(self):
        """
        Gets the created_by of this Document.


        :return: The created_by of this Document.
        :rtype: UriReference
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this Document.


        :param created_by: The created_by of this Document.
        :type: UriReference
        """
        self._created_by = created_by

    @property
    def uploaded_by(self):
        """
        Gets the uploaded_by of this Document.


        :return: The uploaded_by of this Document.
        :rtype: UriReference
        """
        return self._uploaded_by

    @uploaded_by.setter
    def uploaded_by(self, uploaded_by):
        """
        Sets the uploaded_by of this Document.


        :param uploaded_by: The uploaded_by of this Document.
        :type: UriReference
        """
        self._uploaded_by = uploaded_by

    @property
    def content_type(self):
        """
        Gets the content_type of this Document.


        :return: The content_type of this Document.
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """
        Sets the content_type of this Document.


        :param content_type: The content_type of this Document.
        :type: str
        """
        self._content_type = content_type

    @property
    def content_length(self):
        """
        Gets the content_length of this Document.


        :return: The content_length of this Document.
        :rtype: int
        """
        return self._content_length

    @content_length.setter
    def content_length(self, content_length):
        """
        Sets the content_length of this Document.


        :param content_length: The content_length of this Document.
        :type: int
        """
        self._content_length = content_length

    @property
    def system_type(self):
        """
        Gets the system_type of this Document.


        :return: The system_type of this Document.
        :rtype: str
        """
        return self._system_type

    @system_type.setter
    def system_type(self, system_type):
        """
        Sets the system_type of this Document.


        :param system_type: The system_type of this Document.
        :type: str
        """
        allowed_values = ["DOCUMENT", "FAX", "RECORDING"]
        if system_type not in allowed_values:
            raise ValueError(
                "Invalid value for `system_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._system_type = system_type

    @property
    def filename(self):
        """
        Gets the filename of this Document.


        :return: The filename of this Document.
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """
        Sets the filename of this Document.


        :param filename: The filename of this Document.
        :type: str
        """
        self._filename = filename

    @property
    def page_count(self):
        """
        Gets the page_count of this Document.


        :return: The page_count of this Document.
        :rtype: int
        """
        return self._page_count

    @page_count.setter
    def page_count(self, page_count):
        """
        Sets the page_count of this Document.


        :param page_count: The page_count of this Document.
        :type: int
        """
        self._page_count = page_count

    @property
    def read(self):
        """
        Gets the read of this Document.


        :return: The read of this Document.
        :rtype: bool
        """
        return self._read

    @read.setter
    def read(self, read):
        """
        Sets the read of this Document.


        :param read: The read of this Document.
        :type: bool
        """
        self._read = read

    @property
    def caller_address(self):
        """
        Gets the caller_address of this Document.


        :return: The caller_address of this Document.
        :rtype: str
        """
        return self._caller_address

    @caller_address.setter
    def caller_address(self, caller_address):
        """
        Sets the caller_address of this Document.


        :param caller_address: The caller_address of this Document.
        :type: str
        """
        self._caller_address = caller_address

    @property
    def receiver_address(self):
        """
        Gets the receiver_address of this Document.


        :return: The receiver_address of this Document.
        :rtype: str
        """
        return self._receiver_address

    @receiver_address.setter
    def receiver_address(self, receiver_address):
        """
        Sets the receiver_address of this Document.


        :param receiver_address: The receiver_address of this Document.
        :type: str
        """
        self._receiver_address = receiver_address

    @property
    def tags(self):
        """
        Gets the tags of this Document.


        :return: The tags of this Document.
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this Document.


        :param tags: The tags of this Document.
        :type: list[str]
        """
        self._tags = tags

    @property
    def tag_values(self):
        """
        Gets the tag_values of this Document.


        :return: The tag_values of this Document.
        :rtype: list[TagValue]
        """
        return self._tag_values

    @tag_values.setter
    def tag_values(self, tag_values):
        """
        Sets the tag_values of this Document.


        :param tag_values: The tag_values of this Document.
        :type: list[TagValue]
        """
        self._tag_values = tag_values

    @property
    def attributes(self):
        """
        Gets the attributes of this Document.


        :return: The attributes of this Document.
        :rtype: list[DocumentAttribute]
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this Document.


        :param attributes: The attributes of this Document.
        :type: list[DocumentAttribute]
        """
        self._attributes = attributes

    @property
    def thumbnails(self):
        """
        Gets the thumbnails of this Document.


        :return: The thumbnails of this Document.
        :rtype: list[DocumentThumbnail]
        """
        return self._thumbnails

    @thumbnails.setter
    def thumbnails(self, thumbnails):
        """
        Sets the thumbnails of this Document.


        :param thumbnails: The thumbnails of this Document.
        :type: list[DocumentThumbnail]
        """
        self._thumbnails = thumbnails

    @property
    def upload_status(self):
        """
        Gets the upload_status of this Document.


        :return: The upload_status of this Document.
        :rtype: UriReference
        """
        return self._upload_status

    @upload_status.setter
    def upload_status(self, upload_status):
        """
        Sets the upload_status of this Document.


        :param upload_status: The upload_status of this Document.
        :type: UriReference
        """
        self._upload_status = upload_status

    @property
    def upload_destination_uri(self):
        """
        Gets the upload_destination_uri of this Document.


        :return: The upload_destination_uri of this Document.
        :rtype: str
        """
        return self._upload_destination_uri

    @upload_destination_uri.setter
    def upload_destination_uri(self, upload_destination_uri):
        """
        Sets the upload_destination_uri of this Document.


        :param upload_destination_uri: The upload_destination_uri of this Document.
        :type: str
        """
        self._upload_destination_uri = upload_destination_uri

    @property
    def upload_method(self):
        """
        Gets the upload_method of this Document.


        :return: The upload_method of this Document.
        :rtype: str
        """
        return self._upload_method

    @upload_method.setter
    def upload_method(self, upload_method):
        """
        Sets the upload_method of this Document.


        :param upload_method: The upload_method of this Document.
        :type: str
        """
        allowed_values = ["SINGLE_PUT", "MULTIPART_POST"]
        if upload_method not in allowed_values:
            raise ValueError(
                "Invalid value for `upload_method`, must be one of {0}"
                .format(allowed_values)
            )
        self._upload_method = upload_method

    @property
    def lock_info(self):
        """
        Gets the lock_info of this Document.


        :return: The lock_info of this Document.
        :rtype: LockInfo
        """
        return self._lock_info

    @lock_info.setter
    def lock_info(self, lock_info):
        """
        Sets the lock_info of this Document.


        :param lock_info: The lock_info of this Document.
        :type: LockInfo
        """
        self._lock_info = lock_info

    @property
    def acl(self):
        """
        Gets the acl of this Document.
        A list of permitted action rights for the user making the request

        :return: The acl of this Document.
        :rtype: list[str]
        """
        return self._acl

    @acl.setter
    def acl(self, acl):
        """
        Sets the acl of this Document.
        A list of permitted action rights for the user making the request

        :param acl: The acl of this Document.
        :type: list[str]
        """
        self._acl = acl

    @property
    def sharing_status(self):
        """
        Gets the sharing_status of this Document.


        :return: The sharing_status of this Document.
        :rtype: str
        """
        return self._sharing_status

    @sharing_status.setter
    def sharing_status(self, sharing_status):
        """
        Sets the sharing_status of this Document.


        :param sharing_status: The sharing_status of this Document.
        :type: str
        """
        allowed_values = ["NONE", "LIMITED", "PUBLIC"]
        if sharing_status not in allowed_values:
            raise ValueError(
                "Invalid value for `sharing_status`, must be one of {0}"
                .format(allowed_values)
            )
        self._sharing_status = sharing_status

    @property
    def sharing_uri(self):
        """
        Gets the sharing_uri of this Document.


        :return: The sharing_uri of this Document.
        :rtype: str
        """
        return self._sharing_uri

    @sharing_uri.setter
    def sharing_uri(self, sharing_uri):
        """
        Sets the sharing_uri of this Document.


        :param sharing_uri: The sharing_uri of this Document.
        :type: str
        """
        self._sharing_uri = sharing_uri

    @property
    def download_sharing_uri(self):
        """
        Gets the download_sharing_uri of this Document.


        :return: The download_sharing_uri of this Document.
        :rtype: str
        """
        return self._download_sharing_uri

    @download_sharing_uri.setter
    def download_sharing_uri(self, download_sharing_uri):
        """
        Sets the download_sharing_uri of this Document.


        :param download_sharing_uri: The download_sharing_uri of this Document.
        :type: str
        """
        self._download_sharing_uri = download_sharing_uri

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Document.
        The URI for this object

        :return: The self_uri of this Document.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Document.
        The URI for this object

        :param self_uri: The self_uri of this Document.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class CsvSchema(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        CsvSchema - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'carrier_id': 'str',
            'header_row': 'int',
            'data_row': 'int',
            'header_mappings': 'dict(str, str)',
            'rate_type': 'str',
            'name': 'str',
            'date_format': 'str'
        }

        self.attribute_map = {
            'carrier_id': 'CarrierId',
            'header_row': 'HeaderRow',
            'data_row': 'DataRow',
            'header_mappings': 'HeaderMappings',
            'rate_type': 'RateType',
            'name': 'Name',
            'date_format': 'DateFormat'
        }

        self._carrier_id = None
        self._header_row = None
        self._data_row = None
        self._header_mappings = None
        self._rate_type = None
        self._name = None
        self._date_format = None

    @property
    def carrier_id(self):
        """
        Gets the carrier_id of this CsvSchema.
        Carrier ID associated with this CSV schema.

        :return: The carrier_id of this CsvSchema.
        :rtype: str
        """
        return self._carrier_id

    @carrier_id.setter
    def carrier_id(self, carrier_id):
        """
        Sets the carrier_id of this CsvSchema.
        Carrier ID associated with this CSV schema.

        :param carrier_id: The carrier_id of this CsvSchema.
        :type: str
        """
        self._carrier_id = carrier_id

    @property
    def header_row(self):
        """
        Gets the header_row of this CsvSchema.
        Row number for the CSV's headers.  This is zero indexed (i.e. 0 is row 1).

        :return: The header_row of this CsvSchema.
        :rtype: int
        """
        return self._header_row

    @header_row.setter
    def header_row(self, header_row):
        """
        Sets the header_row of this CsvSchema.
        Row number for the CSV's headers.  This is zero indexed (i.e. 0 is row 1).

        :param header_row: The header_row of this CsvSchema.
        :type: int
        """
        self._header_row = header_row

    @property
    def data_row(self):
        """
        Gets the data_row of this CsvSchema.
        Row number of the first line of data.  This is zero indexed (i.e. 0 is row 1).

        :return: The data_row of this CsvSchema.
        :rtype: int
        """
        return self._data_row

    @data_row.setter
    def data_row(self, data_row):
        """
        Sets the data_row of this CsvSchema.
        Row number of the first line of data.  This is zero indexed (i.e. 0 is row 1).

        :param data_row: The data_row of this CsvSchema.
        :type: int
        """
        self._data_row = data_row

    @property
    def header_mappings(self):
        """
        Gets the header_mappings of this CsvSchema.
        CSV header name to object name mappings. For example, \"ROUTE_TEL_PREFIX\" to \"Prefix\" might be one such mapping.

        :return: The header_mappings of this CsvSchema.
        :rtype: dict(str, str)
        """
        return self._header_mappings

    @header_mappings.setter
    def header_mappings(self, header_mappings):
        """
        Sets the header_mappings of this CsvSchema.
        CSV header name to object name mappings. For example, \"ROUTE_TEL_PREFIX\" to \"Prefix\" might be one such mapping.

        :param header_mappings: The header_mappings of this CsvSchema.
        :type: dict(str, str)
        """
        self._header_mappings = header_mappings

    @property
    def rate_type(self):
        """
        Gets the rate_type of this CsvSchema.
        Rate type for the sheet.

        :return: The rate_type of this CsvSchema.
        :rtype: str
        """
        return self._rate_type

    @rate_type.setter
    def rate_type(self, rate_type):
        """
        Sets the rate_type of this CsvSchema.
        Rate type for the sheet.

        :param rate_type: The rate_type of this CsvSchema.
        :type: str
        """
        allowed_values = ["INTRASTATE", "INTERSTATE", "INTERNATIONAL"]
        if rate_type not in allowed_values:
            raise ValueError(
                "Invalid value for `rate_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._rate_type = rate_type

    @property
    def name(self):
        """
        Gets the name of this CsvSchema.
        Human readable name for schema.

        :return: The name of this CsvSchema.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this CsvSchema.
        Human readable name for schema.

        :param name: The name of this CsvSchema.
        :type: str
        """
        self._name = name

    @property
    def date_format(self):
        """
        Gets the date_format of this CsvSchema.
        A date format that represents the date time stamp you want to parse. This is based on the reference time of Mon Jan 2 15:04:05 MST 2006. For example, if you had the date 13-OCT-2015, this parameter should be 02-Jan-2006. As another example, if you have the date 2014-09-20, this parameter should be 2006-01-02.

        :return: The date_format of this CsvSchema.
        :rtype: str
        """
        return self._date_format

    @date_format.setter
    def date_format(self, date_format):
        """
        Sets the date_format of this CsvSchema.
        A date format that represents the date time stamp you want to parse. This is based on the reference time of Mon Jan 2 15:04:05 MST 2006. For example, if you had the date 13-OCT-2015, this parameter should be 02-Jan-2006. As another example, if you have the date 2014-09-20, this parameter should be 2006-01-02.

        :param date_format: The date_format of this CsvSchema.
        :type: str
        """
        self._date_format = date_format

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class DependencyObject(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DependencyObject - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'version': 'str',
            'type': 'str',
            'deleted': 'bool',
            'consumed_resources': 'list[Dependency]',
            'consuming_resources': 'list[Dependency]',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'version': 'version',
            'type': 'type',
            'deleted': 'deleted',
            'consumed_resources': 'consumedResources',
            'consuming_resources': 'consumingResources',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._version = None
        self._type = None
        self._deleted = False
        self._consumed_resources = None
        self._consuming_resources = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this DependencyObject.
        The globally unique identifier for the object.

        :return: The id of this DependencyObject.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DependencyObject.
        The globally unique identifier for the object.

        :param id: The id of this DependencyObject.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DependencyObject.


        :return: The name of this DependencyObject.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DependencyObject.


        :param name: The name of this DependencyObject.
        :type: str
        """
        self._name = name

    @property
    def version(self):
        """
        Gets the version of this DependencyObject.


        :return: The version of this DependencyObject.
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this DependencyObject.


        :param version: The version of this DependencyObject.
        :type: str
        """
        self._version = version

    @property
    def type(self):
        """
        Gets the type of this DependencyObject.


        :return: The type of this DependencyObject.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this DependencyObject.


        :param type: The type of this DependencyObject.
        :type: str
        """
        allowed_values = ["ACDLANGUAGE", "ACDSKILL", "ACDWRAPUPCODE", "BRIDGEACTION", "COMPOSERSCRIPT", "CONTACTLIST", "INBOUNDCALLFLOW", "INQUEUECALLFLOW", "IVRCONFIGURATION", "LANGUAGE", "OUTBOUNDCALLFLOW", "QUEUE", "SYSTEMPROMPT", "USER", "USERPROMPT", "VOICEXML"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def deleted(self):
        """
        Gets the deleted of this DependencyObject.


        :return: The deleted of this DependencyObject.
        :rtype: bool
        """
        return self._deleted

    @deleted.setter
    def deleted(self, deleted):
        """
        Sets the deleted of this DependencyObject.


        :param deleted: The deleted of this DependencyObject.
        :type: bool
        """
        self._deleted = deleted

    @property
    def consumed_resources(self):
        """
        Gets the consumed_resources of this DependencyObject.


        :return: The consumed_resources of this DependencyObject.
        :rtype: list[Dependency]
        """
        return self._consumed_resources

    @consumed_resources.setter
    def consumed_resources(self, consumed_resources):
        """
        Sets the consumed_resources of this DependencyObject.


        :param consumed_resources: The consumed_resources of this DependencyObject.
        :type: list[Dependency]
        """
        self._consumed_resources = consumed_resources

    @property
    def consuming_resources(self):
        """
        Gets the consuming_resources of this DependencyObject.


        :return: The consuming_resources of this DependencyObject.
        :rtype: list[Dependency]
        """
        return self._consuming_resources

    @consuming_resources.setter
    def consuming_resources(self, consuming_resources):
        """
        Sets the consuming_resources of this DependencyObject.


        :param consuming_resources: The consuming_resources of this DependencyObject.
        :type: list[Dependency]
        """
        self._consuming_resources = consuming_resources

    @property
    def self_uri(self):
        """
        Gets the self_uri of this DependencyObject.
        The URI for this object

        :return: The self_uri of this DependencyObject.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this DependencyObject.
        The URI for this object

        :param self_uri: The self_uri of this DependencyObject.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class NumberOrderRequest(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        NumberOrderRequest - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'order_tns': 'list[str]',
            'reservation_ids': 'list[str]',
            'order_id': 'str',
            'effective_date': 'datetime',
            'phone_number_type': 'str'
        }

        self.attribute_map = {
            'order_tns': 'orderTns',
            'reservation_ids': 'reservationIds',
            'order_id': 'orderId',
            'effective_date': 'effectiveDate',
            'phone_number_type': 'phoneNumberType'
        }

        self._order_tns = None
        self._reservation_ids = None
        self._order_id = None
        self._effective_date = None
        self._phone_number_type = None

    @property
    def order_tns(self):
        """
        Gets the order_tns of this NumberOrderRequest.


        :return: The order_tns of this NumberOrderRequest.
        :rtype: list[str]
        """
        return self._order_tns

    @order_tns.setter
    def order_tns(self, order_tns):
        """
        Sets the order_tns of this NumberOrderRequest.


        :param order_tns: The order_tns of this NumberOrderRequest.
        :type: list[str]
        """
        self._order_tns = order_tns

    @property
    def reservation_ids(self):
        """
        Gets the reservation_ids of this NumberOrderRequest.


        :return: The reservation_ids of this NumberOrderRequest.
        :rtype: list[str]
        """
        return self._reservation_ids

    @reservation_ids.setter
    def reservation_ids(self, reservation_ids):
        """
        Sets the reservation_ids of this NumberOrderRequest.


        :param reservation_ids: The reservation_ids of this NumberOrderRequest.
        :type: list[str]
        """
        self._reservation_ids = reservation_ids

    @property
    def order_id(self):
        """
        Gets the order_id of this NumberOrderRequest.


        :return: The order_id of this NumberOrderRequest.
        :rtype: str
        """
        return self._order_id

    @order_id.setter
    def order_id(self, order_id):
        """
        Sets the order_id of this NumberOrderRequest.


        :param order_id: The order_id of this NumberOrderRequest.
        :type: str
        """
        self._order_id = order_id

    @property
    def effective_date(self):
        """
        Gets the effective_date of this NumberOrderRequest.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The effective_date of this NumberOrderRequest.
        :rtype: datetime
        """
        return self._effective_date

    @effective_date.setter
    def effective_date(self, effective_date):
        """
        Sets the effective_date of this NumberOrderRequest.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param effective_date: The effective_date of this NumberOrderRequest.
        :type: datetime
        """
        self._effective_date = effective_date

    @property
    def phone_number_type(self):
        """
        Gets the phone_number_type of this NumberOrderRequest.
        The type of phone number (eg us-domestic, toll-free, etc), to determine which third-party api(s) to use for the order request.

        :return: The phone_number_type of this NumberOrderRequest.
        :rtype: str
        """
        return self._phone_number_type

    @phone_number_type.setter
    def phone_number_type(self, phone_number_type):
        """
        Sets the phone_number_type of this NumberOrderRequest.
        The type of phone number (eg us-domestic, toll-free, etc), to determine which third-party api(s) to use for the order request.

        :param phone_number_type: The phone_number_type of this NumberOrderRequest.
        :type: str
        """
        allowed_values = ["TOLL_FREE", "CN_DOMESTIC", "US_DOMESTIC"]
        if phone_number_type not in allowed_values:
            raise ValueError(
                "Invalid value for `phone_number_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._phone_number_type = phone_number_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Wrapup(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Wrapup - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'code': 'str',
            'name': 'str',
            'notes': 'str',
            'tags': 'list[str]',
            'duration_seconds': 'int',
            'end_time': 'datetime',
            'provisional': 'bool'
        }

        self.attribute_map = {
            'code': 'code',
            'name': 'name',
            'notes': 'notes',
            'tags': 'tags',
            'duration_seconds': 'durationSeconds',
            'end_time': 'endTime',
            'provisional': 'provisional'
        }

        self._code = None
        self._name = None
        self._notes = None
        self._tags = None
        self._duration_seconds = None
        self._end_time = None
        self._provisional = False

    @property
    def code(self):
        """
        Gets the code of this Wrapup.


        :return: The code of this Wrapup.
        :rtype: str
        """
        return self._code

    @code.setter
    def code(self, code):
        """
        Sets the code of this Wrapup.


        :param code: The code of this Wrapup.
        :type: str
        """
        self._code = code

    @property
    def name(self):
        """
        Gets the name of this Wrapup.


        :return: The name of this Wrapup.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Wrapup.


        :param name: The name of this Wrapup.
        :type: str
        """
        self._name = name

    @property
    def notes(self):
        """
        Gets the notes of this Wrapup.


        :return: The notes of this Wrapup.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """
        Sets the notes of this Wrapup.


        :param notes: The notes of this Wrapup.
        :type: str
        """
        self._notes = notes

    @property
    def tags(self):
        """
        Gets the tags of this Wrapup.


        :return: The tags of this Wrapup.
        :rtype: list[str]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this Wrapup.


        :param tags: The tags of this Wrapup.
        :type: list[str]
        """
        self._tags = tags

    @property
    def duration_seconds(self):
        """
        Gets the duration_seconds of this Wrapup.


        :return: The duration_seconds of this Wrapup.
        :rtype: int
        """
        return self._duration_seconds

    @duration_seconds.setter
    def duration_seconds(self, duration_seconds):
        """
        Sets the duration_seconds of this Wrapup.


        :param duration_seconds: The duration_seconds of this Wrapup.
        :type: int
        """
        self._duration_seconds = duration_seconds

    @property
    def end_time(self):
        """
        Gets the end_time of this Wrapup.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The end_time of this Wrapup.
        :rtype: datetime
        """
        return self._end_time

    @end_time.setter
    def end_time(self, end_time):
        """
        Sets the end_time of this Wrapup.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param end_time: The end_time of this Wrapup.
        :type: datetime
        """
        self._end_time = end_time

    @property
    def provisional(self):
        """
        Gets the provisional of this Wrapup.


        :return: The provisional of this Wrapup.
        :rtype: bool
        """
        return self._provisional

    @provisional.setter
    def provisional(self, provisional):
        """
        Sets the provisional of this Wrapup.


        :param provisional: The provisional of this Wrapup.
        :type: bool
        """
        self._provisional = provisional

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Call(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Call - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'state': 'str',
            'id': 'str',
            'direction': 'str',
            'recording': 'bool',
            'recording_state': 'str',
            'muted': 'bool',
            'confined': 'bool',
            'held': 'bool',
            'recording_id': 'str',
            'segments': 'list[Segment]',
            'error_info': 'ErrorBody',
            'disconnect_type': 'str',
            'start_hold_time': 'datetime',
            'document_id': 'str',
            'connected_time': 'datetime',
            'disconnected_time': 'datetime',
            'disconnect_reasons': 'list[DisconnectReason]'
        }

        self.attribute_map = {
            'state': 'state',
            'id': 'id',
            'direction': 'direction',
            'recording': 'recording',
            'recording_state': 'recordingState',
            'muted': 'muted',
            'confined': 'confined',
            'held': 'held',
            'recording_id': 'recordingId',
            'segments': 'segments',
            'error_info': 'errorInfo',
            'disconnect_type': 'disconnectType',
            'start_hold_time': 'startHoldTime',
            'document_id': 'documentId',
            'connected_time': 'connectedTime',
            'disconnected_time': 'disconnectedTime',
            'disconnect_reasons': 'disconnectReasons'
        }

        self._state = None
        self._id = None
        self._direction = None
        self._recording = False
        self._recording_state = None
        self._muted = False
        self._confined = False
        self._held = False
        self._recording_id = None
        self._segments = None
        self._error_info = None
        self._disconnect_type = None
        self._start_hold_time = None
        self._document_id = None
        self._connected_time = None
        self._disconnected_time = None
        self._disconnect_reasons = None

    @property
    def state(self):
        """
        Gets the state of this Call.


        :return: The state of this Call.
        :rtype: str
        """
        return self._state

    @state.setter
    def state(self, state):
        """
        Sets the state of this Call.


        :param state: The state of this Call.
        :type: str
        """
        allowed_values = ["ALERTING", "DIALING", "CONTACTING", "OFFERING", "CONNECTED", "DISCONNECTED", "TERMINATED", "CONVERTING", "UPLOADING", "TRANSMITTING", "NONE"]
        if state not in allowed_values:
            raise ValueError(
                "Invalid value for `state`, must be one of {0}"
                .format(allowed_values)
            )
        self._state = state

    @property
    def id(self):
        """
        Gets the id of this Call.


        :return: The id of this Call.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Call.


        :param id: The id of this Call.
        :type: str
        """
        self._id = id

    @property
    def direction(self):
        """
        Gets the direction of this Call.


        :return: The direction of this Call.
        :rtype: str
        """
        return self._direction

    @direction.setter
    def direction(self, direction):
        """
        Sets the direction of this Call.


        :param direction: The direction of this Call.
        :type: str
        """
        allowed_values = ["INBOUND", "OUTBOUND"]
        if direction not in allowed_values:
            raise ValueError(
                "Invalid value for `direction`, must be one of {0}"
                .format(allowed_values)
            )
        self._direction = direction

    @property
    def recording(self):
        """
        Gets the recording of this Call.


        :return: The recording of this Call.
        :rtype: bool
        """
        return self._recording

    @recording.setter
    def recording(self, recording):
        """
        Sets the recording of this Call.


        :param recording: The recording of this Call.
        :type: bool
        """
        self._recording = recording

    @property
    def recording_state(self):
        """
        Gets the recording_state of this Call.


        :return: The recording_state of this Call.
        :rtype: str
        """
        return self._recording_state

    @recording_state.setter
    def recording_state(self, recording_state):
        """
        Sets the recording_state of this Call.


        :param recording_state: The recording_state of this Call.
        :type: str
        """
        allowed_values = ["NONE", "ACTIVE", "PAUSED"]
        if recording_state not in allowed_values:
            raise ValueError(
                "Invalid value for `recording_state`, must be one of {0}"
                .format(allowed_values)
            )
        self._recording_state = recording_state

    @property
    def muted(self):
        """
        Gets the muted of this Call.


        :return: The muted of this Call.
        :rtype: bool
        """
        return self._muted

    @muted.setter
    def muted(self, muted):
        """
        Sets the muted of this Call.


        :param muted: The muted of this Call.
        :type: bool
        """
        self._muted = muted

    @property
    def confined(self):
        """
        Gets the confined of this Call.


        :return: The confined of this Call.
        :rtype: bool
        """
        return self._confined

    @confined.setter
    def confined(self, confined):
        """
        Sets the confined of this Call.


        :param confined: The confined of this Call.
        :type: bool
        """
        self._confined = confined

    @property
    def held(self):
        """
        Gets the held of this Call.


        :return: The held of this Call.
        :rtype: bool
        """
        return self._held

    @held.setter
    def held(self, held):
        """
        Sets the held of this Call.


        :param held: The held of this Call.
        :type: bool
        """
        self._held = held

    @property
    def recording_id(self):
        """
        Gets the recording_id of this Call.


        :return: The recording_id of this Call.
        :rtype: str
        """
        return self._recording_id

    @recording_id.setter
    def recording_id(self, recording_id):
        """
        Sets the recording_id of this Call.


        :param recording_id: The recording_id of this Call.
        :type: str
        """
        self._recording_id = recording_id

    @property
    def segments(self):
        """
        Gets the segments of this Call.


        :return: The segments of this Call.
        :rtype: list[Segment]
        """
        return self._segments

    @segments.setter
    def segments(self, segments):
        """
        Sets the segments of this Call.


        :param segments: The segments of this Call.
        :type: list[Segment]
        """
        self._segments = segments

    @property
    def error_info(self):
        """
        Gets the error_info of this Call.


        :return: The error_info of this Call.
        :rtype: ErrorBody
        """
        return self._error_info

    @error_info.setter
    def error_info(self, error_info):
        """
        Sets the error_info of this Call.


        :param error_info: The error_info of this Call.
        :type: ErrorBody
        """
        self._error_info = error_info

    @property
    def disconnect_type(self):
        """
        Gets the disconnect_type of this Call.


        :return: The disconnect_type of this Call.
        :rtype: str
        """
        return self._disconnect_type

    @disconnect_type.setter
    def disconnect_type(self, disconnect_type):
        """
        Sets the disconnect_type of this Call.


        :param disconnect_type: The disconnect_type of this Call.
        :type: str
        """
        allowed_values = ["ENDPOINT", "CLIENT", "SYSTEM", "TIMEOUT", "TRANSFER", "TRANSFER_CONFERENCE", "TRANSFER_CONSULT", "TRANSFER_FORWARD", "ERROR", "PEER", "OTHER"]
        if disconnect_type not in allowed_values:
            raise ValueError(
                "Invalid value for `disconnect_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._disconnect_type = disconnect_type

    @property
    def start_hold_time(self):
        """
        Gets the start_hold_time of this Call.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The start_hold_time of this Call.
        :rtype: datetime
        """
        return self._start_hold_time

    @start_hold_time.setter
    def start_hold_time(self, start_hold_time):
        """
        Sets the start_hold_time of this Call.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param start_hold_time: The start_hold_time of this Call.
        :type: datetime
        """
        self._start_hold_time = start_hold_time

    @property
    def document_id(self):
        """
        Gets the document_id of this Call.


        :return: The document_id of this Call.
        :rtype: str
        """
        return self._document_id

    @document_id.setter
    def document_id(self, document_id):
        """
        Sets the document_id of this Call.


        :param document_id: The document_id of this Call.
        :type: str
        """
        self._document_id = document_id

    @property
    def connected_time(self):
        """
        Gets the connected_time of this Call.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The connected_time of this Call.
        :rtype: datetime
        """
        return self._connected_time

    @connected_time.setter
    def connected_time(self, connected_time):
        """
        Sets the connected_time of this Call.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param connected_time: The connected_time of this Call.
        :type: datetime
        """
        self._connected_time = connected_time

    @property
    def disconnected_time(self):
        """
        Gets the disconnected_time of this Call.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The disconnected_time of this Call.
        :rtype: datetime
        """
        return self._disconnected_time

    @disconnected_time.setter
    def disconnected_time(self, disconnected_time):
        """
        Sets the disconnected_time of this Call.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param disconnected_time: The disconnected_time of this Call.
        :type: datetime
        """
        self._disconnected_time = disconnected_time

    @property
    def disconnect_reasons(self):
        """
        Gets the disconnect_reasons of this Call.


        :return: The disconnect_reasons of this Call.
        :rtype: list[DisconnectReason]
        """
        return self._disconnect_reasons

    @disconnect_reasons.setter
    def disconnect_reasons(self, disconnect_reasons):
        """
        Sets the disconnect_reasons of this Call.


        :param disconnect_reasons: The disconnect_reasons of this Call.
        :type: list[DisconnectReason]
        """
        self._disconnect_reasons = disconnect_reasons

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class DeltaDocument(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        DeltaDocument - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'filename': 'str',
            'content_type': 'str',
            'content_length_bytes': 'int',
            'operation': 'str',
            'date_modified': 'datetime'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'filename': 'filename',
            'content_type': 'contentType',
            'content_length_bytes': 'contentLengthBytes',
            'operation': 'operation',
            'date_modified': 'dateModified'
        }

        self._id = None
        self._name = None
        self._filename = None
        self._content_type = None
        self._content_length_bytes = None
        self._operation = None
        self._date_modified = None

    @property
    def id(self):
        """
        Gets the id of this DeltaDocument.


        :return: The id of this DeltaDocument.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this DeltaDocument.


        :param id: The id of this DeltaDocument.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this DeltaDocument.


        :return: The name of this DeltaDocument.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this DeltaDocument.


        :param name: The name of this DeltaDocument.
        :type: str
        """
        self._name = name

    @property
    def filename(self):
        """
        Gets the filename of this DeltaDocument.


        :return: The filename of this DeltaDocument.
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """
        Sets the filename of this DeltaDocument.


        :param filename: The filename of this DeltaDocument.
        :type: str
        """
        self._filename = filename

    @property
    def content_type(self):
        """
        Gets the content_type of this DeltaDocument.


        :return: The content_type of this DeltaDocument.
        :rtype: str
        """
        return self._content_type

    @content_type.setter
    def content_type(self, content_type):
        """
        Sets the content_type of this DeltaDocument.


        :param content_type: The content_type of this DeltaDocument.
        :type: str
        """
        self._content_type = content_type

    @property
    def content_length_bytes(self):
        """
        Gets the content_length_bytes of this DeltaDocument.


        :return: The content_length_bytes of this DeltaDocument.
        :rtype: int
        """
        return self._content_length_bytes

    @content_length_bytes.setter
    def content_length_bytes(self, content_length_bytes):
        """
        Sets the content_length_bytes of this DeltaDocument.


        :param content_length_bytes: The content_length_bytes of this DeltaDocument.
        :type: int
        """
        self._content_length_bytes = content_length_bytes

    @property
    def operation(self):
        """
        Gets the operation of this DeltaDocument.


        :return: The operation of this DeltaDocument.
        :rtype: str
        """
        return self._operation

    @operation.setter
    def operation(self, operation):
        """
        Sets the operation of this DeltaDocument.


        :param operation: The operation of this DeltaDocument.
        :type: str
        """
        allowed_values = ["CREATED", "UPDATED", "REPLACED", "DELETED"]
        if operation not in allowed_values:
            raise ValueError(
                "Invalid value for `operation`, must be one of {0}"
                .format(allowed_values)
            )
        self._operation = operation

    @property
    def date_modified(self):
        """
        Gets the date_modified of this DeltaDocument.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The date_modified of this DeltaDocument.
        :rtype: datetime
        """
        return self._date_modified

    @date_modified.setter
    def date_modified(self, date_modified):
        """
        Sets the date_modified of this DeltaDocument.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param date_modified: The date_modified of this DeltaDocument.
        :type: datetime
        """
        self._date_modified = date_modified

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class SubDataItem(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SubDataItem - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'type': 'str',
            'value': 'str',
            'prompt': 'str',
            'display_value': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'type': 'type',
            'value': 'value',
            'prompt': 'prompt',
            'display_value': 'displayValue'
        }

        self._id = None
        self._type = None
        self._value = None
        self._prompt = None
        self._display_value = None

    @property
    def id(self):
        """
        Gets the id of this SubDataItem.
        The id of this element

        :return: The id of this SubDataItem.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this SubDataItem.
        The id of this element

        :param id: The id of this SubDataItem.
        :type: str
        """
        self._id = id

    @property
    def type(self):
        """
        Gets the type of this SubDataItem.
        The 'type' of the element, this may be a system value, EG 'STRING' or a user defined type

        :return: The type of this SubDataItem.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this SubDataItem.
        The 'type' of the element, this may be a system value, EG 'STRING' or a user defined type

        :param type: The type of this SubDataItem.
        :type: str
        """
        self._type = type

    @property
    def value(self):
        """
        Gets the value of this SubDataItem.
        The value of the element itself - This may be a simple value or more complex serialized data.

        :return: The value of this SubDataItem.
        :rtype: str
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this SubDataItem.
        The value of the element itself - This may be a simple value or more complex serialized data.

        :param value: The value of this SubDataItem.
        :type: str
        """
        self._value = value

    @property
    def prompt(self):
        """
        Gets the prompt of this SubDataItem.
        The prompt displayed to the user that this data item was set from.

        :return: The prompt of this SubDataItem.
        :rtype: str
        """
        return self._prompt

    @prompt.setter
    def prompt(self, prompt):
        """
        Sets the prompt of this SubDataItem.
        The prompt displayed to the user that this data item was set from.

        :param prompt: The prompt of this SubDataItem.
        :type: str
        """
        self._prompt = prompt

    @property
    def display_value(self):
        """
        Gets the display_value of this SubDataItem.
        The display value that was offered to the user (as opposed to the actual value used internally

        :return: The display_value of this SubDataItem.
        :rtype: str
        """
        return self._display_value

    @display_value.setter
    def display_value(self, display_value):
        """
        Sets the display_value of this SubDataItem.
        The display value that was offered to the user (as opposed to the actual value used internally

        :param display_value: The display_value of this SubDataItem.
        :type: str
        """
        self._display_value = display_value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class WorkItemDetails(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WorkItemDetails - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'work_item_definition': 'WorkItemDefinition',
            'flow_exec_id': 'FlowExecId',
            'flow_config_id': 'FlowConfigId',
            'flow_create_time': 'datetime',
            'create_time': 'datetime',
            'owner': 'User',
            'offered_to_users': 'list[User]',
            'offered_to_queues': 'list[Queue]',
            'title': 'str',
            'subtitle': 'str',
            'associated_documents': 'list[AssociatedDocument]',
            'available_actions': 'WorkItemActions',
            'data_value_info': 'DataValueInfo',
            'work_item_cache': 'WorkItemCache',
            'last_offered_time': 'datetime',
            'last_ownership_update_time': 'datetime',
            'current_task_start_time': 'datetime',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'work_item_definition': 'workItemDefinition',
            'flow_exec_id': 'flowExecId',
            'flow_config_id': 'flowConfigId',
            'flow_create_time': 'flowCreateTime',
            'create_time': 'createTime',
            'owner': 'owner',
            'offered_to_users': 'offeredToUsers',
            'offered_to_queues': 'offeredToQueues',
            'title': 'title',
            'subtitle': 'subtitle',
            'associated_documents': 'associatedDocuments',
            'available_actions': 'availableActions',
            'data_value_info': 'dataValueInfo',
            'work_item_cache': 'workItemCache',
            'last_offered_time': 'lastOfferedTime',
            'last_ownership_update_time': 'lastOwnershipUpdateTime',
            'current_task_start_time': 'currentTaskStartTime',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._work_item_definition = None
        self._flow_exec_id = None
        self._flow_config_id = None
        self._flow_create_time = None
        self._create_time = None
        self._owner = None
        self._offered_to_users = None
        self._offered_to_queues = None
        self._title = None
        self._subtitle = None
        self._associated_documents = None
        self._available_actions = None
        self._data_value_info = None
        self._work_item_cache = None
        self._last_offered_time = None
        self._last_ownership_update_time = None
        self._current_task_start_time = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this WorkItemDetails.
        The globally unique identifier for the object.

        :return: The id of this WorkItemDetails.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WorkItemDetails.
        The globally unique identifier for the object.

        :param id: The id of this WorkItemDetails.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this WorkItemDetails.


        :return: The name of this WorkItemDetails.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this WorkItemDetails.


        :param name: The name of this WorkItemDetails.
        :type: str
        """
        self._name = name

    @property
    def work_item_definition(self):
        """
        Gets the work_item_definition of this WorkItemDetails.


        :return: The work_item_definition of this WorkItemDetails.
        :rtype: WorkItemDefinition
        """
        return self._work_item_definition

    @work_item_definition.setter
    def work_item_definition(self, work_item_definition):
        """
        Sets the work_item_definition of this WorkItemDetails.


        :param work_item_definition: The work_item_definition of this WorkItemDetails.
        :type: WorkItemDefinition
        """
        self._work_item_definition = work_item_definition

    @property
    def flow_exec_id(self):
        """
        Gets the flow_exec_id of this WorkItemDetails.
        The flow instance ID that created this WorkItem

        :return: The flow_exec_id of this WorkItemDetails.
        :rtype: FlowExecId
        """
        return self._flow_exec_id

    @flow_exec_id.setter
    def flow_exec_id(self, flow_exec_id):
        """
        Sets the flow_exec_id of this WorkItemDetails.
        The flow instance ID that created this WorkItem

        :param flow_exec_id: The flow_exec_id of this WorkItemDetails.
        :type: FlowExecId
        """
        self._flow_exec_id = flow_exec_id

    @property
    def flow_config_id(self):
        """
        Gets the flow_config_id of this WorkItemDetails.
        The flow config ID that this workitem was created from.

        :return: The flow_config_id of this WorkItemDetails.
        :rtype: FlowConfigId
        """
        return self._flow_config_id

    @flow_config_id.setter
    def flow_config_id(self, flow_config_id):
        """
        Sets the flow_config_id of this WorkItemDetails.
        The flow config ID that this workitem was created from.

        :param flow_config_id: The flow_config_id of this WorkItemDetails.
        :type: FlowConfigId
        """
        self._flow_config_id = flow_config_id

    @property
    def flow_create_time(self):
        """
        Gets the flow_create_time of this WorkItemDetails.
        The time the flow was started. (that created this workitem). Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The flow_create_time of this WorkItemDetails.
        :rtype: datetime
        """
        return self._flow_create_time

    @flow_create_time.setter
    def flow_create_time(self, flow_create_time):
        """
        Sets the flow_create_time of this WorkItemDetails.
        The time the flow was started. (that created this workitem). Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param flow_create_time: The flow_create_time of this WorkItemDetails.
        :type: datetime
        """
        self._flow_create_time = flow_create_time

    @property
    def create_time(self):
        """
        Gets the create_time of this WorkItemDetails.
        The time this workitem was started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The create_time of this WorkItemDetails.
        :rtype: datetime
        """
        return self._create_time

    @create_time.setter
    def create_time(self, create_time):
        """
        Sets the create_time of this WorkItemDetails.
        The time this workitem was started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param create_time: The create_time of this WorkItemDetails.
        :type: datetime
        """
        self._create_time = create_time

    @property
    def owner(self):
        """
        Gets the owner of this WorkItemDetails.
        The user currently working on/has responsibility for this WorkItem.  May be null if no owner.

        :return: The owner of this WorkItemDetails.
        :rtype: User
        """
        return self._owner

    @owner.setter
    def owner(self, owner):
        """
        Sets the owner of this WorkItemDetails.
        The user currently working on/has responsibility for this WorkItem.  May be null if no owner.

        :param owner: The owner of this WorkItemDetails.
        :type: User
        """
        self._owner = owner

    @property
    def offered_to_users(self):
        """
        Gets the offered_to_users of this WorkItemDetails.
        List of users that this workItem is offered to.  May be null if only offered to queues.

        :return: The offered_to_users of this WorkItemDetails.
        :rtype: list[User]
        """
        return self._offered_to_users

    @offered_to_users.setter
    def offered_to_users(self, offered_to_users):
        """
        Sets the offered_to_users of this WorkItemDetails.
        List of users that this workItem is offered to.  May be null if only offered to queues.

        :param offered_to_users: The offered_to_users of this WorkItemDetails.
        :type: list[User]
        """
        self._offered_to_users = offered_to_users

    @property
    def offered_to_queues(self):
        """
        Gets the offered_to_queues of this WorkItemDetails.
        List of queues that this workItem is offered to.  May be null if only offered to users.

        :return: The offered_to_queues of this WorkItemDetails.
        :rtype: list[Queue]
        """
        return self._offered_to_queues

    @offered_to_queues.setter
    def offered_to_queues(self, offered_to_queues):
        """
        Sets the offered_to_queues of this WorkItemDetails.
        List of queues that this workItem is offered to.  May be null if only offered to users.

        :param offered_to_queues: The offered_to_queues of this WorkItemDetails.
        :type: list[Queue]
        """
        self._offered_to_queues = offered_to_queues

    @property
    def title(self):
        """
        Gets the title of this WorkItemDetails.
        The work item title

        :return: The title of this WorkItemDetails.
        :rtype: str
        """
        return self._title

    @title.setter
    def title(self, title):
        """
        Sets the title of this WorkItemDetails.
        The work item title

        :param title: The title of this WorkItemDetails.
        :type: str
        """
        self._title = title

    @property
    def subtitle(self):
        """
        Gets the subtitle of this WorkItemDetails.
        The work item's subtitle - 2nd line/description

        :return: The subtitle of this WorkItemDetails.
        :rtype: str
        """
        return self._subtitle

    @subtitle.setter
    def subtitle(self, subtitle):
        """
        Sets the subtitle of this WorkItemDetails.
        The work item's subtitle - 2nd line/description

        :param subtitle: The subtitle of this WorkItemDetails.
        :type: str
        """
        self._subtitle = subtitle

    @property
    def associated_documents(self):
        """
        Gets the associated_documents of this WorkItemDetails.
        The documents associated with this workitem

        :return: The associated_documents of this WorkItemDetails.
        :rtype: list[AssociatedDocument]
        """
        return self._associated_documents

    @associated_documents.setter
    def associated_documents(self, associated_documents):
        """
        Sets the associated_documents of this WorkItemDetails.
        The documents associated with this workitem

        :param associated_documents: The associated_documents of this WorkItemDetails.
        :type: list[AssociatedDocument]
        """
        self._associated_documents = associated_documents

    @property
    def available_actions(self):
        """
        Gets the available_actions of this WorkItemDetails.
        The actions that the user can take on this workitem (submit, transfer, etc).

        :return: The available_actions of this WorkItemDetails.
        :rtype: WorkItemActions
        """
        return self._available_actions

    @available_actions.setter
    def available_actions(self, available_actions):
        """
        Sets the available_actions of this WorkItemDetails.
        The actions that the user can take on this workitem (submit, transfer, etc).

        :param available_actions: The available_actions of this WorkItemDetails.
        :type: WorkItemActions
        """
        self._available_actions = available_actions

    @property
    def data_value_info(self):
        """
        Gets the data_value_info of this WorkItemDetails.
        The data items that provide values for any work item form elements, if applicable.

        :return: The data_value_info of this WorkItemDetails.
        :rtype: DataValueInfo
        """
        return self._data_value_info

    @data_value_info.setter
    def data_value_info(self, data_value_info):
        """
        Sets the data_value_info of this WorkItemDetails.
        The data items that provide values for any work item form elements, if applicable.

        :param data_value_info: The data_value_info of this WorkItemDetails.
        :type: DataValueInfo
        """
        self._data_value_info = data_value_info

    @property
    def work_item_cache(self):
        """
        Gets the work_item_cache of this WorkItemDetails.
        The data items in the current work item cache, if one exists.

        :return: The work_item_cache of this WorkItemDetails.
        :rtype: WorkItemCache
        """
        return self._work_item_cache

    @work_item_cache.setter
    def work_item_cache(self, work_item_cache):
        """
        Sets the work_item_cache of this WorkItemDetails.
        The data items in the current work item cache, if one exists.

        :param work_item_cache: The work_item_cache of this WorkItemDetails.
        :type: WorkItemCache
        """
        self._work_item_cache = work_item_cache

    @property
    def last_offered_time(self):
        """
        Gets the last_offered_time of this WorkItemDetails.
        The time this work item was last offered to a user or queue. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The last_offered_time of this WorkItemDetails.
        :rtype: datetime
        """
        return self._last_offered_time

    @last_offered_time.setter
    def last_offered_time(self, last_offered_time):
        """
        Sets the last_offered_time of this WorkItemDetails.
        The time this work item was last offered to a user or queue. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param last_offered_time: The last_offered_time of this WorkItemDetails.
        :type: datetime
        """
        self._last_offered_time = last_offered_time

    @property
    def last_ownership_update_time(self):
        """
        Gets the last_ownership_update_time of this WorkItemDetails.
        The most recent time a user assumed ownership of a work item. This may be blank if the work item has no owner. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The last_ownership_update_time of this WorkItemDetails.
        :rtype: datetime
        """
        return self._last_ownership_update_time

    @last_ownership_update_time.setter
    def last_ownership_update_time(self, last_ownership_update_time):
        """
        Sets the last_ownership_update_time of this WorkItemDetails.
        The most recent time a user assumed ownership of a work item. This may be blank if the work item has no owner. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param last_ownership_update_time: The last_ownership_update_time of this WorkItemDetails.
        :type: datetime
        """
        self._last_ownership_update_time = last_ownership_update_time

    @property
    def current_task_start_time(self):
        """
        Gets the current_task_start_time of this WorkItemDetails.
        This is the time when the current task that started the work item was started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The current_task_start_time of this WorkItemDetails.
        :rtype: datetime
        """
        return self._current_task_start_time

    @current_task_start_time.setter
    def current_task_start_time(self, current_task_start_time):
        """
        Sets the current_task_start_time of this WorkItemDetails.
        This is the time when the current task that started the work item was started. Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param current_task_start_time: The current_task_start_time of this WorkItemDetails.
        :type: datetime
        """
        self._current_task_start_time = current_task_start_time

    @property
    def self_uri(self):
        """
        Gets the self_uri of this WorkItemDetails.
        The URI for this object

        :return: The self_uri of this WorkItemDetails.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this WorkItemDetails.
        The URI for this object

        :param self_uri: The self_uri of this WorkItemDetails.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class FlowVersion(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        FlowVersion - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'commit_version': 'str',
            'configuration_version': 'str',
            'type': 'str',
            'created_by': 'UriReference',
            'configuration_uri': 'str',
            'date_created': 'int',
            'generation_id': 'str',
            'publish_result_uri': 'str',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'commit_version': 'commitVersion',
            'configuration_version': 'configurationVersion',
            'type': 'type',
            'created_by': 'createdBy',
            'configuration_uri': 'configurationUri',
            'date_created': 'dateCreated',
            'generation_id': 'generationId',
            'publish_result_uri': 'publishResultUri',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._commit_version = None
        self._configuration_version = None
        self._type = None
        self._created_by = None
        self._configuration_uri = None
        self._date_created = None
        self._generation_id = None
        self._publish_result_uri = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this FlowVersion.
        The globally unique identifier for the object.

        :return: The id of this FlowVersion.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this FlowVersion.
        The globally unique identifier for the object.

        :param id: The id of this FlowVersion.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this FlowVersion.


        :return: The name of this FlowVersion.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this FlowVersion.


        :param name: The name of this FlowVersion.
        :type: str
        """
        self._name = name

    @property
    def commit_version(self):
        """
        Gets the commit_version of this FlowVersion.


        :return: The commit_version of this FlowVersion.
        :rtype: str
        """
        return self._commit_version

    @commit_version.setter
    def commit_version(self, commit_version):
        """
        Sets the commit_version of this FlowVersion.


        :param commit_version: The commit_version of this FlowVersion.
        :type: str
        """
        self._commit_version = commit_version

    @property
    def configuration_version(self):
        """
        Gets the configuration_version of this FlowVersion.


        :return: The configuration_version of this FlowVersion.
        :rtype: str
        """
        return self._configuration_version

    @configuration_version.setter
    def configuration_version(self, configuration_version):
        """
        Sets the configuration_version of this FlowVersion.


        :param configuration_version: The configuration_version of this FlowVersion.
        :type: str
        """
        self._configuration_version = configuration_version

    @property
    def type(self):
        """
        Gets the type of this FlowVersion.


        :return: The type of this FlowVersion.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this FlowVersion.


        :param type: The type of this FlowVersion.
        :type: str
        """
        allowed_values = ["PUBLISH", "CHECKIN", "SAVE"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type`, must be one of {0}"
                .format(allowed_values)
            )
        self._type = type

    @property
    def created_by(self):
        """
        Gets the created_by of this FlowVersion.


        :return: The created_by of this FlowVersion.
        :rtype: UriReference
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """
        Sets the created_by of this FlowVersion.


        :param created_by: The created_by of this FlowVersion.
        :type: UriReference
        """
        self._created_by = created_by

    @property
    def configuration_uri(self):
        """
        Gets the configuration_uri of this FlowVersion.


        :return: The configuration_uri of this FlowVersion.
        :rtype: str
        """
        return self._configuration_uri

    @configuration_uri.setter
    def configuration_uri(self, configuration_uri):
        """
        Sets the configuration_uri of this FlowVersion.


        :param configuration_uri: The configuration_uri of this FlowVersion.
        :type: str
        """
        self._configuration_uri = configuration_uri

    @property
    def date_created(self):
        """
        Gets the date_created of this FlowVersion.


        :return: The date_created of this FlowVersion.
        :rtype: int
        """
        return self._date_created

    @date_created.setter
    def date_created(self, date_created):
        """
        Sets the date_created of this FlowVersion.


        :param date_created: The date_created of this FlowVersion.
        :type: int
        """
        self._date_created = date_created

    @property
    def generation_id(self):
        """
        Gets the generation_id of this FlowVersion.


        :return: The generation_id of this FlowVersion.
        :rtype: str
        """
        return self._generation_id

    @generation_id.setter
    def generation_id(self, generation_id):
        """
        Sets the generation_id of this FlowVersion.


        :param generation_id: The generation_id of this FlowVersion.
        :type: str
        """
        self._generation_id = generation_id

    @property
    def publish_result_uri(self):
        """
        Gets the publish_result_uri of this FlowVersion.


        :return: The publish_result_uri of this FlowVersion.
        :rtype: str
        """
        return self._publish_result_uri

    @publish_result_uri.setter
    def publish_result_uri(self, publish_result_uri):
        """
        Sets the publish_result_uri of this FlowVersion.


        :param publish_result_uri: The publish_result_uri of this FlowVersion.
        :type: str
        """
        self._publish_result_uri = publish_result_uri

    @property
    def self_uri(self):
        """
        Gets the self_uri of this FlowVersion.
        The URI for this object

        :return: The self_uri of this FlowVersion.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this FlowVersion.
        The URI for this object

        :param self_uri: The self_uri of this FlowVersion.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class WorkItemDefinition(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        WorkItemDefinition - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'command_categories': 'list[WorkItemCommandGroup]',
            'form': 'Form'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'command_categories': 'commandCategories',
            'form': 'form'
        }

        self._id = None
        self._name = None
        self._command_categories = None
        self._form = None

    @property
    def id(self):
        """
        Gets the id of this WorkItemDefinition.
        The configuration ID for this workItem

        :return: The id of this WorkItemDefinition.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this WorkItemDefinition.
        The configuration ID for this workItem

        :param id: The id of this WorkItemDefinition.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this WorkItemDefinition.


        :return: The name of this WorkItemDefinition.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this WorkItemDefinition.


        :param name: The name of this WorkItemDefinition.
        :type: str
        """
        self._name = name

    @property
    def command_categories(self):
        """
        Gets the command_categories of this WorkItemDefinition.
        The commands that can be performed on this work item

        :return: The command_categories of this WorkItemDefinition.
        :rtype: list[WorkItemCommandGroup]
        """
        return self._command_categories

    @command_categories.setter
    def command_categories(self, command_categories):
        """
        Sets the command_categories of this WorkItemDefinition.
        The commands that can be performed on this work item

        :param command_categories: The command_categories of this WorkItemDefinition.
        :type: list[WorkItemCommandGroup]
        """
        self._command_categories = command_categories

    @property
    def form(self):
        """
        Gets the form of this WorkItemDefinition.
        The simple work item form containging the control to present for this work item

        :return: The form of this WorkItemDefinition.
        :rtype: Form
        """
        return self._form

    @form.setter
    def form(self, form):
        """
        Sets the form of this WorkItemDefinition.
        The simple work item form containging the control to present for this work item

        :param form: The form of this WorkItemDefinition.
        :type: Form
        """
        self._form = form

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class SheetSchema(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        SheetSchema - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'header_row': 'int',
            'data_row': 'int',
            'header_mappings': 'dict(str, str)',
            'rate_type': 'str',
            'sheet_number': 'int',
            'date_format': 'str'
        }

        self.attribute_map = {
            'header_row': 'HeaderRow',
            'data_row': 'DataRow',
            'header_mappings': 'HeaderMappings',
            'rate_type': 'RateType',
            'sheet_number': 'SheetNumber',
            'date_format': 'DateFormat'
        }

        self._header_row = None
        self._data_row = None
        self._header_mappings = None
        self._rate_type = None
        self._sheet_number = None
        self._date_format = None

    @property
    def header_row(self):
        """
        Gets the header_row of this SheetSchema.
        Row number for the XLSX sheet's headers.  This is zero indexed (i.e. 0 is row 1).

        :return: The header_row of this SheetSchema.
        :rtype: int
        """
        return self._header_row

    @header_row.setter
    def header_row(self, header_row):
        """
        Sets the header_row of this SheetSchema.
        Row number for the XLSX sheet's headers.  This is zero indexed (i.e. 0 is row 1).

        :param header_row: The header_row of this SheetSchema.
        :type: int
        """
        self._header_row = header_row

    @property
    def data_row(self):
        """
        Gets the data_row of this SheetSchema.
        Row number of the first line of data in the sheet.  This is zero indexed (i.e. 0 is row 1)

        :return: The data_row of this SheetSchema.
        :rtype: int
        """
        return self._data_row

    @data_row.setter
    def data_row(self, data_row):
        """
        Sets the data_row of this SheetSchema.
        Row number of the first line of data in the sheet.  This is zero indexed (i.e. 0 is row 1)

        :param data_row: The data_row of this SheetSchema.
        :type: int
        """
        self._data_row = data_row

    @property
    def header_mappings(self):
        """
        Gets the header_mappings of this SheetSchema.
        XLSX sheet header name to object name mappings. For example, \"ROUTE_TEL_PREFIX\" to \"Prefix\" might be one such mapping.

        :return: The header_mappings of this SheetSchema.
        :rtype: dict(str, str)
        """
        return self._header_mappings

    @header_mappings.setter
    def header_mappings(self, header_mappings):
        """
        Sets the header_mappings of this SheetSchema.
        XLSX sheet header name to object name mappings. For example, \"ROUTE_TEL_PREFIX\" to \"Prefix\" might be one such mapping.

        :param header_mappings: The header_mappings of this SheetSchema.
        :type: dict(str, str)
        """
        self._header_mappings = header_mappings

    @property
    def rate_type(self):
        """
        Gets the rate_type of this SheetSchema.
        Rate type for the sheet.

        :return: The rate_type of this SheetSchema.
        :rtype: str
        """
        return self._rate_type

    @rate_type.setter
    def rate_type(self, rate_type):
        """
        Sets the rate_type of this SheetSchema.
        Rate type for the sheet.

        :param rate_type: The rate_type of this SheetSchema.
        :type: str
        """
        allowed_values = ["INTRASTATE", "INTERSTATE", "INTERNATIONAL"]
        if rate_type not in allowed_values:
            raise ValueError(
                "Invalid value for `rate_type`, must be one of {0}"
                .format(allowed_values)
            )
        self._rate_type = rate_type

    @property
    def sheet_number(self):
        """
        Gets the sheet_number of this SheetSchema.
        Sheet number within the XLSX file.  This is zero indexed (i.e. 0 is page 1).

        :return: The sheet_number of this SheetSchema.
        :rtype: int
        """
        return self._sheet_number

    @sheet_number.setter
    def sheet_number(self, sheet_number):
        """
        Sets the sheet_number of this SheetSchema.
        Sheet number within the XLSX file.  This is zero indexed (i.e. 0 is page 1).

        :param sheet_number: The sheet_number of this SheetSchema.
        :type: int
        """
        self._sheet_number = sheet_number

    @property
    def date_format(self):
        """
        Gets the date_format of this SheetSchema.
        A date format that represents the date time stamp you want to parse. This is based on the reference time of Mon Jan 2 15:04:05 MST 2006. For example, if you had the date 13-OCT-2015, this parameter should be 02-Jan-2006. As another example, if you have the date 2014-09-20, this parameter should be 2006-01-02.

        :return: The date_format of this SheetSchema.
        :rtype: str
        """
        return self._date_format

    @date_format.setter
    def date_format(self, date_format):
        """
        Sets the date_format of this SheetSchema.
        A date format that represents the date time stamp you want to parse. This is based on the reference time of Mon Jan 2 15:04:05 MST 2006. For example, if you had the date 13-OCT-2015, this parameter should be 02-Jan-2006. As another example, if you have the date 2014-09-20, this parameter should be 2006-01-02.

        :param date_format: The date_format of this SheetSchema.
        :type: str
        """
        self._date_format = date_format

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
LanguagesApi.py
Copyright 2016 SmartBear Software

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
"""

from __future__ import absolute_import

import sys
import os

# python 2 and python 3 compatibility library
from six import iteritems

from ..configuration import Configuration
from ..api_client import ApiClient


class LanguagesApi(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        config = Configuration()
        if api_client:
            self.api_client = api_client
        else:
            if not config.api_client:
                config.api_client = ApiClient()
            self.api_client = config.api_client

    def delete_language_id(self, language_id, **kwargs):
        """
        Delete Language
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.delete_language_id(language_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str language_id: Language ID (required)
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['language_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method delete_language_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'language_id' is set
        if ('language_id' not in params) or (params['language_id'] is None):
            raise ValueError("Missing the required parameter `language_id` when calling `delete_language_id`")

        resource_path = '/api/v2/languages/{languageId}'.replace('{format}', 'json')
        path_params = {}
        if 'language_id' in params:
            path_params['languageId'] = params['language_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'DELETE',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type=None,
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_language_id(self, language_id, **kwargs):
        """
        Get language
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_language_id(language_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str language_id: Language ID (required)
        :return: Language
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['language_id']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_language_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'language_id' is set
        if ('language_id' not in params) or (params['language_id'] is None):
            raise ValueError("Missing the required parameter `language_id` when calling `get_language_id`")

        resource_path = '/api/v2/languages/{languageId}'.replace('{format}', 'json')
        path_params = {}
        if 'language_id' in params:
            path_params['languageId'] = params['language_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Language',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def get_languages(self, **kwargs):
        """
        Get the list of supported languages.
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.get_languages(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param int page_size: Page size
        :param int page_number: Page number
        :param str sort_order: Ascending or descending sort order
        :return: LanguageEntityListing
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['page_size', 'page_number', 'sort_order']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_languages" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/languages'.replace('{format}', 'json')
        path_params = {}

        query_params = {}
        if 'page_size' in params:
            query_params['pageSize'] = params['page_size']
        if 'page_number' in params:
            query_params['pageNumber'] = params['page_number']
        if 'sort_order' in params:
            query_params['sortOrder'] = params['sort_order']

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'GET',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='LanguageEntityListing',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def post_languages(self, **kwargs):
        """
        Create Language
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.post_languages(callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param Language body: Language
        :return: Language
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method post_languages" % key
                )
            params[key] = val
        del params['kwargs']


        resource_path = '/api/v2/languages'.replace('{format}', 'json')
        path_params = {}

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'POST',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Language',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response

    def put_language_id(self, language_id, **kwargs):
        """
        Update Language
        

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please define a `callback` function
        to be invoked when receiving the response.
        >>> def callback_function(response):
        >>>     pprint(response)
        >>>
        >>> thread = api.put_language_id(language_id, callback=callback_function)

        :param callback function: The callback function
            for asynchronous request. (optional)
        :param str language_id: Language ID (required)
        :param Language body: Language
        :return: Language
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['language_id', 'body']
        all_params.append('callback')

        params = locals()
        for key, val in iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method put_language_id" % key
                )
            params[key] = val
        del params['kwargs']

        # verify the required parameter 'language_id' is set
        if ('language_id' not in params) or (params['language_id'] is None):
            raise ValueError("Missing the required parameter `language_id` when calling `put_language_id`")

        resource_path = '/api/v2/languages/{languageId}'.replace('{format}', 'json')
        path_params = {}
        if 'language_id' in params:
            path_params['languageId'] = params['language_id']

        query_params = {}

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']

        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.\
            select_header_accept(['application/json'])
        if not header_params['Accept']:
            del header_params['Accept']

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.\
            select_header_content_type(['application/json'])

        # Authentication setting
        auth_settings = ['PureCloud Auth']

        response = self.api_client.call_api(resource_path, 'PUT',
                                            path_params,
                                            query_params,
                                            header_params,
                                            body=body_params,
                                            post_params=form_params,
                                            files=local_var_files,
                                            response_type='Language',
                                            auth_settings=auth_settings,
                                            callback=params.get('callback'))
        return response



# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class Script(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        Script - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'name': 'str',
            'version_id': 'str',
            'created_date': 'datetime',
            'modified_date': 'datetime',
            'published_date': 'datetime',
            'version_date': 'datetime',
            'start_page_id': 'str',
            'start_page_name': 'str',
            'features': 'object',
            'variables': 'object',
            'custom_actions': 'object',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'name': 'name',
            'version_id': 'versionId',
            'created_date': 'createdDate',
            'modified_date': 'modifiedDate',
            'published_date': 'publishedDate',
            'version_date': 'versionDate',
            'start_page_id': 'startPageId',
            'start_page_name': 'startPageName',
            'features': 'features',
            'variables': 'variables',
            'custom_actions': 'customActions',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._name = None
        self._version_id = None
        self._created_date = None
        self._modified_date = None
        self._published_date = None
        self._version_date = None
        self._start_page_id = None
        self._start_page_name = None
        self._features = None
        self._variables = None
        self._custom_actions = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this Script.
        The globally unique identifier for the object.

        :return: The id of this Script.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this Script.
        The globally unique identifier for the object.

        :param id: The id of this Script.
        :type: str
        """
        self._id = id

    @property
    def name(self):
        """
        Gets the name of this Script.


        :return: The name of this Script.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Script.


        :param name: The name of this Script.
        :type: str
        """
        self._name = name

    @property
    def version_id(self):
        """
        Gets the version_id of this Script.


        :return: The version_id of this Script.
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """
        Sets the version_id of this Script.


        :param version_id: The version_id of this Script.
        :type: str
        """
        self._version_id = version_id

    @property
    def created_date(self):
        """
        Gets the created_date of this Script.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The created_date of this Script.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this Script.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param created_date: The created_date of this Script.
        :type: datetime
        """
        self._created_date = created_date

    @property
    def modified_date(self):
        """
        Gets the modified_date of this Script.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The modified_date of this Script.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this Script.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param modified_date: The modified_date of this Script.
        :type: datetime
        """
        self._modified_date = modified_date

    @property
    def published_date(self):
        """
        Gets the published_date of this Script.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The published_date of this Script.
        :rtype: datetime
        """
        return self._published_date

    @published_date.setter
    def published_date(self, published_date):
        """
        Sets the published_date of this Script.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param published_date: The published_date of this Script.
        :type: datetime
        """
        self._published_date = published_date

    @property
    def version_date(self):
        """
        Gets the version_date of this Script.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The version_date of this Script.
        :rtype: datetime
        """
        return self._version_date

    @version_date.setter
    def version_date(self, version_date):
        """
        Sets the version_date of this Script.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param version_date: The version_date of this Script.
        :type: datetime
        """
        self._version_date = version_date

    @property
    def start_page_id(self):
        """
        Gets the start_page_id of this Script.


        :return: The start_page_id of this Script.
        :rtype: str
        """
        return self._start_page_id

    @start_page_id.setter
    def start_page_id(self, start_page_id):
        """
        Sets the start_page_id of this Script.


        :param start_page_id: The start_page_id of this Script.
        :type: str
        """
        self._start_page_id = start_page_id

    @property
    def start_page_name(self):
        """
        Gets the start_page_name of this Script.


        :return: The start_page_name of this Script.
        :rtype: str
        """
        return self._start_page_name

    @start_page_name.setter
    def start_page_name(self, start_page_name):
        """
        Sets the start_page_name of this Script.


        :param start_page_name: The start_page_name of this Script.
        :type: str
        """
        self._start_page_name = start_page_name

    @property
    def features(self):
        """
        Gets the features of this Script.


        :return: The features of this Script.
        :rtype: object
        """
        return self._features

    @features.setter
    def features(self, features):
        """
        Sets the features of this Script.


        :param features: The features of this Script.
        :type: object
        """
        self._features = features

    @property
    def variables(self):
        """
        Gets the variables of this Script.


        :return: The variables of this Script.
        :rtype: object
        """
        return self._variables

    @variables.setter
    def variables(self, variables):
        """
        Sets the variables of this Script.


        :param variables: The variables of this Script.
        :type: object
        """
        self._variables = variables

    @property
    def custom_actions(self):
        """
        Gets the custom_actions of this Script.


        :return: The custom_actions of this Script.
        :rtype: object
        """
        return self._custom_actions

    @custom_actions.setter
    def custom_actions(self, custom_actions):
        """
        Sets the custom_actions of this Script.


        :param custom_actions: The custom_actions of this Script.
        :type: object
        """
        self._custom_actions = custom_actions

    @property
    def self_uri(self):
        """
        Gets the self_uri of this Script.
        The URI for this object

        :return: The self_uri of this Script.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this Script.
        The URI for this object

        :param self_uri: The self_uri of this Script.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class VoicemailMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        VoicemailMessage - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'conversation': 'Conversation',
            'read': 'bool',
            'audio_recording_duration_seconds': 'int',
            'audio_recording_size_bytes': 'int',
            'created_date': 'datetime',
            'modified_date': 'datetime',
            'caller_address': 'str',
            'caller_name': 'str',
            'caller_user': 'User',
            'self_uri': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'conversation': 'conversation',
            'read': 'read',
            'audio_recording_duration_seconds': 'audioRecordingDurationSeconds',
            'audio_recording_size_bytes': 'audioRecordingSizeBytes',
            'created_date': 'createdDate',
            'modified_date': 'modifiedDate',
            'caller_address': 'callerAddress',
            'caller_name': 'callerName',
            'caller_user': 'callerUser',
            'self_uri': 'selfUri'
        }

        self._id = None
        self._conversation = None
        self._read = False
        self._audio_recording_duration_seconds = None
        self._audio_recording_size_bytes = None
        self._created_date = None
        self._modified_date = None
        self._caller_address = None
        self._caller_name = None
        self._caller_user = None
        self._self_uri = None

    @property
    def id(self):
        """
        Gets the id of this VoicemailMessage.
        The globally unique identifier for the object.

        :return: The id of this VoicemailMessage.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this VoicemailMessage.
        The globally unique identifier for the object.

        :param id: The id of this VoicemailMessage.
        :type: str
        """
        self._id = id

    @property
    def conversation(self):
        """
        Gets the conversation of this VoicemailMessage.


        :return: The conversation of this VoicemailMessage.
        :rtype: Conversation
        """
        return self._conversation

    @conversation.setter
    def conversation(self, conversation):
        """
        Sets the conversation of this VoicemailMessage.


        :param conversation: The conversation of this VoicemailMessage.
        :type: Conversation
        """
        self._conversation = conversation

    @property
    def read(self):
        """
        Gets the read of this VoicemailMessage.


        :return: The read of this VoicemailMessage.
        :rtype: bool
        """
        return self._read

    @read.setter
    def read(self, read):
        """
        Sets the read of this VoicemailMessage.


        :param read: The read of this VoicemailMessage.
        :type: bool
        """
        self._read = read

    @property
    def audio_recording_duration_seconds(self):
        """
        Gets the audio_recording_duration_seconds of this VoicemailMessage.


        :return: The audio_recording_duration_seconds of this VoicemailMessage.
        :rtype: int
        """
        return self._audio_recording_duration_seconds

    @audio_recording_duration_seconds.setter
    def audio_recording_duration_seconds(self, audio_recording_duration_seconds):
        """
        Sets the audio_recording_duration_seconds of this VoicemailMessage.


        :param audio_recording_duration_seconds: The audio_recording_duration_seconds of this VoicemailMessage.
        :type: int
        """
        self._audio_recording_duration_seconds = audio_recording_duration_seconds

    @property
    def audio_recording_size_bytes(self):
        """
        Gets the audio_recording_size_bytes of this VoicemailMessage.


        :return: The audio_recording_size_bytes of this VoicemailMessage.
        :rtype: int
        """
        return self._audio_recording_size_bytes

    @audio_recording_size_bytes.setter
    def audio_recording_size_bytes(self, audio_recording_size_bytes):
        """
        Sets the audio_recording_size_bytes of this VoicemailMessage.


        :param audio_recording_size_bytes: The audio_recording_size_bytes of this VoicemailMessage.
        :type: int
        """
        self._audio_recording_size_bytes = audio_recording_size_bytes

    @property
    def created_date(self):
        """
        Gets the created_date of this VoicemailMessage.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The created_date of this VoicemailMessage.
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """
        Sets the created_date of this VoicemailMessage.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param created_date: The created_date of this VoicemailMessage.
        :type: datetime
        """
        self._created_date = created_date

    @property
    def modified_date(self):
        """
        Gets the modified_date of this VoicemailMessage.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :return: The modified_date of this VoicemailMessage.
        :rtype: datetime
        """
        return self._modified_date

    @modified_date.setter
    def modified_date(self, modified_date):
        """
        Sets the modified_date of this VoicemailMessage.
        Date time is represented as an ISO-8601 string. For example: yyyy-MM-ddTHH:mm:ss.SSSZ

        :param modified_date: The modified_date of this VoicemailMessage.
        :type: datetime
        """
        self._modified_date = modified_date

    @property
    def caller_address(self):
        """
        Gets the caller_address of this VoicemailMessage.


        :return: The caller_address of this VoicemailMessage.
        :rtype: str
        """
        return self._caller_address

    @caller_address.setter
    def caller_address(self, caller_address):
        """
        Sets the caller_address of this VoicemailMessage.


        :param caller_address: The caller_address of this VoicemailMessage.
        :type: str
        """
        self._caller_address = caller_address

    @property
    def caller_name(self):
        """
        Gets the caller_name of this VoicemailMessage.


        :return: The caller_name of this VoicemailMessage.
        :rtype: str
        """
        return self._caller_name

    @caller_name.setter
    def caller_name(self, caller_name):
        """
        Sets the caller_name of this VoicemailMessage.


        :param caller_name: The caller_name of this VoicemailMessage.
        :type: str
        """
        self._caller_name = caller_name

    @property
    def caller_user(self):
        """
        Gets the caller_user of this VoicemailMessage.


        :return: The caller_user of this VoicemailMessage.
        :rtype: User
        """
        return self._caller_user

    @caller_user.setter
    def caller_user(self, caller_user):
        """
        Sets the caller_user of this VoicemailMessage.


        :param caller_user: The caller_user of this VoicemailMessage.
        :type: User
        """
        self._caller_user = caller_user

    @property
    def self_uri(self):
        """
        Gets the self_uri of this VoicemailMessage.
        The URI for this object

        :return: The self_uri of this VoicemailMessage.
        :rtype: str
        """
        return self._self_uri

    @self_uri.setter
    def self_uri(self, self_uri):
        """
        Sets the self_uri of this VoicemailMessage.
        The URI for this object

        :param self_uri: The self_uri of this VoicemailMessage.
        :type: str
        """
        self._self_uri = self_uri

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class ConversationQuery(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        ConversationQuery - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'interval': 'str',
            'conversation_filters': 'list[AnalyticsQueryFilter]',
            'evaluation_filters': 'list[AnalyticsQueryFilter]',
            'segment_filters': 'list[AnalyticsQueryFilter]',
            'aggregations': 'list[AnalyticsQueryAggregation]',
            'paging': 'PagingSpec',
            'order': 'str',
            'order_by': 'str'
        }

        self.attribute_map = {
            'interval': 'interval',
            'conversation_filters': 'conversationFilters',
            'evaluation_filters': 'evaluationFilters',
            'segment_filters': 'segmentFilters',
            'aggregations': 'aggregations',
            'paging': 'paging',
            'order': 'order',
            'order_by': 'orderBy'
        }

        self._interval = None
        self._conversation_filters = None
        self._evaluation_filters = None
        self._segment_filters = None
        self._aggregations = None
        self._paging = None
        self._order = None
        self._order_by = None

    @property
    def interval(self):
        """
        Gets the interval of this ConversationQuery.
        Specifies the date and time range of data being queried. Conversations MUST have started within this time range to potentially be included within the result set. Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss

        :return: The interval of this ConversationQuery.
        :rtype: str
        """
        return self._interval

    @interval.setter
    def interval(self, interval):
        """
        Sets the interval of this ConversationQuery.
        Specifies the date and time range of data being queried. Conversations MUST have started within this time range to potentially be included within the result set. Intervals are represented as an ISO-8601 string. For example: YYYY-MM-DDThh:mm:ss/YYYY-MM-DDThh:mm:ss

        :param interval: The interval of this ConversationQuery.
        :type: str
        """
        self._interval = interval

    @property
    def conversation_filters(self):
        """
        Gets the conversation_filters of this ConversationQuery.
        Filters that target conversation-level data

        :return: The conversation_filters of this ConversationQuery.
        :rtype: list[AnalyticsQueryFilter]
        """
        return self._conversation_filters

    @conversation_filters.setter
    def conversation_filters(self, conversation_filters):
        """
        Sets the conversation_filters of this ConversationQuery.
        Filters that target conversation-level data

        :param conversation_filters: The conversation_filters of this ConversationQuery.
        :type: list[AnalyticsQueryFilter]
        """
        self._conversation_filters = conversation_filters

    @property
    def evaluation_filters(self):
        """
        Gets the evaluation_filters of this ConversationQuery.
        Filters that target quality management evaluation-level data

        :return: The evaluation_filters of this ConversationQuery.
        :rtype: list[AnalyticsQueryFilter]
        """
        return self._evaluation_filters

    @evaluation_filters.setter
    def evaluation_filters(self, evaluation_filters):
        """
        Sets the evaluation_filters of this ConversationQuery.
        Filters that target quality management evaluation-level data

        :param evaluation_filters: The evaluation_filters of this ConversationQuery.
        :type: list[AnalyticsQueryFilter]
        """
        self._evaluation_filters = evaluation_filters

    @property
    def segment_filters(self):
        """
        Gets the segment_filters of this ConversationQuery.
        Filters that target individual segments within a conversation

        :return: The segment_filters of this ConversationQuery.
        :rtype: list[AnalyticsQueryFilter]
        """
        return self._segment_filters

    @segment_filters.setter
    def segment_filters(self, segment_filters):
        """
        Sets the segment_filters of this ConversationQuery.
        Filters that target individual segments within a conversation

        :param segment_filters: The segment_filters of this ConversationQuery.
        :type: list[AnalyticsQueryFilter]
        """
        self._segment_filters = segment_filters

    @property
    def aggregations(self):
        """
        Gets the aggregations of this ConversationQuery.
        Include faceted search and aggregate roll-ups describing your search results. This does not function as a filter, but rather, summary data about the data matching your filters

        :return: The aggregations of this ConversationQuery.
        :rtype: list[AnalyticsQueryAggregation]
        """
        return self._aggregations

    @aggregations.setter
    def aggregations(self, aggregations):
        """
        Sets the aggregations of this ConversationQuery.
        Include faceted search and aggregate roll-ups describing your search results. This does not function as a filter, but rather, summary data about the data matching your filters

        :param aggregations: The aggregations of this ConversationQuery.
        :type: list[AnalyticsQueryAggregation]
        """
        self._aggregations = aggregations

    @property
    def paging(self):
        """
        Gets the paging of this ConversationQuery.
        Page size and number to control iterating through large result sets. Default page size is 25

        :return: The paging of this ConversationQuery.
        :rtype: PagingSpec
        """
        return self._paging

    @paging.setter
    def paging(self, paging):
        """
        Sets the paging of this ConversationQuery.
        Page size and number to control iterating through large result sets. Default page size is 25

        :param paging: The paging of this ConversationQuery.
        :type: PagingSpec
        """
        self._paging = paging

    @property
    def order(self):
        """
        Gets the order of this ConversationQuery.
        Sort the result set in ascending/descending order. Default is ascending

        :return: The order of this ConversationQuery.
        :rtype: str
        """
        return self._order

    @order.setter
    def order(self, order):
        """
        Sets the order of this ConversationQuery.
        Sort the result set in ascending/descending order. Default is ascending

        :param order: The order of this ConversationQuery.
        :type: str
        """
        allowed_values = ["asc", "desc"]
        if order not in allowed_values:
            raise ValueError(
                "Invalid value for `order`, must be one of {0}"
                .format(allowed_values)
            )
        self._order = order

    @property
    def order_by(self):
        """
        Gets the order_by of this ConversationQuery.
        Specify which data element within the result set to use for sorting. The options  to use as a basis for sorting the results: conversationStart, segmentStart, and segmentEnd. If not specified, the default is conversationStart

        :return: The order_by of this ConversationQuery.
        :rtype: str
        """
        return self._order_by

    @order_by.setter
    def order_by(self, order_by):
        """
        Sets the order_by of this ConversationQuery.
        Specify which data element within the result set to use for sorting. The options  to use as a basis for sorting the results: conversationStart, segmentStart, and segmentEnd. If not specified, the default is conversationStart

        :param order_by: The order_by of this ConversationQuery.
        :type: str
        """
        allowed_values = ["conversationStart", "segmentStart", "segmentEnd"]
        if order_by not in allowed_values:
            raise ValueError(
                "Invalid value for `order_by`, must be one of {0}"
                .format(allowed_values)
            )
        self._order_by = order_by

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other




# coding: utf-8

"""
Copyright 2016 SmartBear Software

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

    Ref: https://github.com/swagger-api/swagger-codegen
"""

from pprint import pformat
from six import iteritems


class QuoteCharge(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self):
        """
        QuoteCharge - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'sku': 'str',
            'name': 'str',
            'charge_type': 'str',
            'quantity': 'int',
            'list_total': 'str',
            'total': 'str',
            'list_price_display': 'str',
            'discount': 'str',
            'effective_price': 'str',
            'product_shippable': 'bool',
            'shipping_address': 'BillingAddress',
            'for_related_part': 'str'
        }

        self.attribute_map = {
            'id': 'id',
            'sku': 'sku',
            'name': 'name',
            'charge_type': 'chargeType',
            'quantity': 'quantity',
            'list_total': 'listTotal',
            'total': 'total',
            'list_price_display': 'listPriceDisplay',
            'discount': 'discount',
            'effective_price': 'effectivePrice',
            'product_shippable': 'productShippable',
            'shipping_address': 'shippingAddress',
            'for_related_part': 'forRelatedPart'
        }

        self._id = None
        self._sku = None
        self._name = None
        self._charge_type = None
        self._quantity = None
        self._list_total = None
        self._total = None
        self._list_price_display = None
        self._discount = None
        self._effective_price = None
        self._product_shippable = False
        self._shipping_address = None
        self._for_related_part = None

    @property
    def id(self):
        """
        Gets the id of this QuoteCharge.
        The quote charge Id.

        :return: The id of this QuoteCharge.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this QuoteCharge.
        The quote charge Id.

        :param id: The id of this QuoteCharge.
        :type: str
        """
        self._id = id

    @property
    def sku(self):
        """
        Gets the sku of this QuoteCharge.
        The quote charge SKU.

        :return: The sku of this QuoteCharge.
        :rtype: str
        """
        return self._sku

    @sku.setter
    def sku(self, sku):
        """
        Sets the sku of this QuoteCharge.
        The quote charge SKU.

        :param sku: The sku of this QuoteCharge.
        :type: str
        """
        self._sku = sku

    @property
    def name(self):
        """
        Gets the name of this QuoteCharge.
        The quote charge name.

        :return: The name of this QuoteCharge.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this QuoteCharge.
        The quote charge name.

        :param name: The name of this QuoteCharge.
        :type: str
        """
        self._name = name

    @property
    def charge_type(self):
        """
        Gets the charge_type of this QuoteCharge.
        The quote charge type.

        :return: The charge_type of this QuoteCharge.
        :rtype: str
        """
        return self._charge_type

    @charge_type.setter
    def charge_type(self, charge_type):
        """
        Sets the charge_type of this QuoteCharge.
        The quote charge type.

        :param charge_type: The charge_type of this QuoteCharge.
        :type: str
        """
        self._charge_type = charge_type

    @property
    def quantity(self):
        """
        Gets the quantity of this QuoteCharge.
        The quote charge quantity.

        :return: The quantity of this QuoteCharge.
        :rtype: int
        """
        return self._quantity

    @quantity.setter
    def quantity(self, quantity):
        """
        Sets the quantity of this QuoteCharge.
        The quote charge quantity.

        :param quantity: The quantity of this QuoteCharge.
        :type: int
        """
        self._quantity = quantity

    @property
    def list_total(self):
        """
        Gets the list_total of this QuoteCharge.
        The quote charge total price before discounts.

        :return: The list_total of this QuoteCharge.
        :rtype: str
        """
        return self._list_total

    @list_total.setter
    def list_total(self, list_total):
        """
        Sets the list_total of this QuoteCharge.
        The quote charge total price before discounts.

        :param list_total: The list_total of this QuoteCharge.
        :type: str
        """
        self._list_total = list_total

    @property
    def total(self):
        """
        Gets the total of this QuoteCharge.
        The quote charge total price after discounts.

        :return: The total of this QuoteCharge.
        :rtype: str
        """
        return self._total

    @total.setter
    def total(self, total):
        """
        Sets the total of this QuoteCharge.
        The quote charge total price after discounts.

        :param total: The total of this QuoteCharge.
        :type: str
        """
        self._total = total

    @property
    def list_price_display(self):
        """
        Gets the list_price_display of this QuoteCharge.
        The quote charge list price before discounts.

        :return: The list_price_display of this QuoteCharge.
        :rtype: str
        """
        return self._list_price_display

    @list_price_display.setter
    def list_price_display(self, list_price_display):
        """
        Sets the list_price_display of this QuoteCharge.
        The quote charge list price before discounts.

        :param list_price_display: The list_price_display of this QuoteCharge.
        :type: str
        """
        self._list_price_display = list_price_display

    @property
    def discount(self):
        """
        Gets the discount of this QuoteCharge.
        The quote charge discount percent.

        :return: The discount of this QuoteCharge.
        :rtype: str
        """
        return self._discount

    @discount.setter
    def discount(self, discount):
        """
        Sets the discount of this QuoteCharge.
        The quote charge discount percent.

        :param discount: The discount of this QuoteCharge.
        :type: str
        """
        self._discount = discount

    @property
    def effective_price(self):
        """
        Gets the effective_price of this QuoteCharge.
        The quote charge list price after discounts.

        :return: The effective_price of this QuoteCharge.
        :rtype: str
        """
        return self._effective_price

    @effective_price.setter
    def effective_price(self, effective_price):
        """
        Sets the effective_price of this QuoteCharge.
        The quote charge list price after discounts.

        :param effective_price: The effective_price of this QuoteCharge.
        :type: str
        """
        self._effective_price = effective_price

    @property
    def product_shippable(self):
        """
        Gets the product_shippable of this QuoteCharge.
        Indicates whether the product can be shipped.

        :return: The product_shippable of this QuoteCharge.
        :rtype: bool
        """
        return self._product_shippable

    @product_shippable.setter
    def product_shippable(self, product_shippable):
        """
        Sets the product_shippable of this QuoteCharge.
        Indicates whether the product can be shipped.

        :param product_shippable: The product_shippable of this QuoteCharge.
        :type: bool
        """
        self._product_shippable = product_shippable

    @property
    def shipping_address(self):
        """
        Gets the shipping_address of this QuoteCharge.
        The quote shipping address.

        :return: The shipping_address of this QuoteCharge.
        :rtype: BillingAddress
        """
        return self._shipping_address

    @shipping_address.setter
    def shipping_address(self, shipping_address):
        """
        Sets the shipping_address of this QuoteCharge.
        The quote shipping address.

        :param shipping_address: The shipping_address of this QuoteCharge.
        :type: BillingAddress
        """
        self._shipping_address = shipping_address

    @property
    def for_related_part(self):
        """
        Gets the for_related_part of this QuoteCharge.
        The part number of a part related to the quote charge.

        :return: The for_related_part of this QuoteCharge.
        :rtype: str
        """
        return self._for_related_part

    @for_related_part.setter
    def for_related_part(self, for_related_part):
        """
        Sets the for_related_part of this QuoteCharge.
        The part number of a part related to the quote charge.

        :param for_related_part: The for_related_part of this QuoteCharge.
        :type: str
        """
        self._for_related_part = for_related_part

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other

